Learn R Programming

BayesH (version 1.0)

get.scale.bayesH: Get the vector of the scale hyperparameter

Description

Get the vector of the scale hyperparameter.

Usage

get.scale.bayesH(nu0, R2 = 0.5, X, y, type = "bayesH")

Arguments

nu0
the vector with shape parameter(s) of (hyper) prior distribution for variance of each the regression coefficient(s) and error variance.
R2
the expected proportion of the variance of the response variable that can be explained by the model (r squared).
y
the vector of response variable of the model.
X
the incidence matrix.
type
it is a string which if were defined as ``ridge'' the function performs Bayesian ridge regression, otherwise, Bayes H model.

Value

vector with values of the scale parameters.

Details

The user must be provided the vector nu0 and all elements this vector must be greater than zero. The strategy adopted here is based on Perez et. al. (2010).

References

Perez. et. al. (2010). Genomic-Enabled Prediction Based on Molecular Markers and Pedigree Using the Bayesian Linear Regression Package in R. Plant Genome. 2010; 3(2): 106-116. doi: 10.3835/plantgenome2010.04.0005.

See Also

bayesModel.fit